(**************************************************************)
(*
 *  Ensemble, (Version 0.70p1)
 *  Copyright 2000 Cornell University
 *  All rights reserved.
 *
 *  See ensemble/doc/license.txt for further information.
 *)
(**************************************************************)
(**************************************************************)
(* DISP.MLI *)
(* Author: Mark Hayden, 4/95 *)
(* Based on code by Werner Vogels *)
(**************************************************************)

val l : ('a,'a,unit) Layer.basic
